@@ -31,7 +31,7 @@ has pubsub => sub {
   return $pubsub;
 };
 
-our $VERSION = '2.07';
+our $VERSION = '2.08';
 
 sub db {
   my $self = shift;
@@ -302,8 +302,8 @@ following new ones.
 
 Get L<Mojo::Pg::Database> object for a cached or newly established database
 connection. The L<DBD::Pg> database handle will be automatically cached again
-when that object is destroyed, so you can handle connection timeouts gracefully
-by holding on to it only for short amounts of time.
+when that object is destroyed, so you can handle problems like connection
+timeouts gracefully by holding on to it only for short amounts of time.
 
   # Add up all the money
   say $pg->db->query('select * from accounts')
@@ -377,6 +377,8 @@ In alphabetical order:
 
 =over 2
 
+Dan Book
+
 Hernan Lopes
 
 =back
